import { env } from '$env/dynamic/public';
import { readable, writable } from 'svelte/store';


function createMemberStore() {
    const { subscribe, set, update } = writable(null)

    return {
        subscribe: subscribe,
        set: set,
        addIntro: (intro: IntroIndex) => { update((n) => n.intros.push(intro)); return intro },
        pullData: async (token) => {
            const response = (await (await fetch(
                `https://${env.PUBLIC_API_URL}/memes/api/me`,
                { headers: {"token": token} })).json())

            if (response === "NoUserFound") {
                return;
            } else {
                set({ token: token, ...response.Me }) 
            }
        }
    }
}

function createIntroStore() {
    const { subscribe, set, update } = writable(new Map())

    return {
        subscribe: subscribe,
        addIntro: async (guild, url, title, token) => {
            const response = await fetch(`https://${env.PUBLIC_API_URL}/memes/api/intros/${guild}/add?url=${encodeURIComponent(url)}&name=${encodeURIComponent(title)}`,
                                         { method: 'GET', headers: { 'token': token } });

            if (!response.ok) {
                throw new Error(await response.body);
            }
        },
        fetchIntros: async (guilds) => {
            let intros = new Map();

            for (const guild of guilds) {
                const response = (await (await fetch(`https://${env.PUBLIC_API_URL}/memes/api/intros/${guild.name}`)).json())
                    if (response !== "NoGuildFound") {
                    let guild_intros = new Map();

                    Object.entries(response.Intros).forEach(([index, intro]) => {
                        if (!!intro.File) {
                            guild_intros.set(index, { name: intro.File.friendlyName, filename: intro.File.filename });
                        } else if (!!intro.Online) {
                            guild_intros.set(index, { name: intro.Online.friendlyName, filename: intro.Online.filename });
                        }
                    })

                    intros.set(guild.name, guild_intros);
                }
            }

            set(intros)
        }
    }
}

export const intros = createIntroStore()
export const member = createMemberStore()

